function OnInit(initData)
{
	initData.name = "hidext";
	initData.version = "1.0 (July 13th, 2018)";
	initData.desc = "Hide (or show) by extension";
	initData.copyright = "(c) 2018 Aussie";
	initData.default_enable = true;
	
	initData.vars("name") = initData.name;
	initData.vars("version") = initData.version;
	initData.vars("minver") = "12";
	
	var cmd = initData.AddCommand();
	cmd.name = initData.name;
	cmd.method = "do_main";
	cmd.desc = initData.desc;
	cmd.label = initData.name;
	cmd.template = "show/s";
	
	initData.config_desc = DOpus.create.map();
	initData.config.dbg = true;
	initData.config_desc("dbg") = 'Write trace information to "Other" log.';
}

//-- Add String methods, courtesy of @tbone
//-- See https://resource.dopus.com/t/filter-bar-match-two-or-more-strings/25944/7

String.prototype.lTrim = function(chr){chr=chr||"\\s";return new String(this.replace(new RegExp("^"+chr+"*"),''));}
String.prototype.rTrim = function(chr){chr=chr||"\\s";return new String(this.replace(new RegExp(chr+"*$"),''));}
String.prototype.trim = function(chr){return this.lTrim(chr).rTrim(chr);}
String.prototype.left = function(chrs){return this.substring(0,chrs);}
String.prototype.right = function(chrs){return this.substring(this.length-chrs);}
String.prototype.contains = function (s,nocs){return (nocs?this.toUpperCase():this).indexOf(nocs?s.toUpperCase():s)>=0;};
String.prototype.startsWith = function (s,nocs){return (nocs?this.toUpperCase():this).indexOf(nocs?s.toUpperCase():s)==0;};
String.prototype.endsWith = function (s,nocs){return (nocs?this.toUpperCase():this).slice(-s.length)==(nocs?s.toUpperCase():s);};

//-- Global Variables

var d, f, fsu, dlg, dbg, c, src;
var me = "hidext";
var foldersarehidden = false;
var show;

//-- Main script code

function do_main(ScriptCommandData)
{
	d = ScriptCommandData;
	f = d.func;
	fsu = DOpus.FSUtil;
	c = f.Command;
	src = f.sourcetab;
	dlg = src.Dlg;
	show = (f.args.got_arg.show);
	
	// Debug ?
	dbg = debug();
	// Establish minimum version requirements
	if (!minver()) return;
	// Do the business
	var res = do_process();
}

//-- This is where stuff gets done

function debug(){
	var dbg = (typeof Script.config.dbg=="undefined") ? true : Script.config.dbg;
	if (dbg){
		var str = (Script.vars.exists("version")) ? Script.vars("version") : "1.0";
		DOpus.output("version " + str + " starting..");
	}
	return dbg;
}

function do_process(){
	// Prepare a dialog
	dlg.template = me;	
	dlg.detach = true;
	var str = (Script.vars.exists("version")) ? Script.vars("version") : "1.0";
	dlg.title = me + " " + str;
	var cmdstr = "";
	dlg.Create;
	// Add any pre-configuration stuff here.
	var listbox = dlg.control("listbox1");
	populate_listbox(listbox);
	listbox.SelectItem(0);
	var usermsg = dlg.control("static1");
	refresh_message(usermsg);
	// Display the dialog
	dlg.Show();
	do {
		var msg = dlg.GetMsg();
		var ctl = msg.control;
		var evnt = msg.event;
		if (dbg) DOpus.output("Control / Event = " + ctl + " / " + evnt);
		if (ctl.left(6)=="button"){
			var lbl = dlg.control(ctl).label;
			if (lbl=="Quit") break; // Quit
			else if (lbl=="Folders"){
				toggle_folders();
				continue;
			};
			else if (lbl=="Toggle"){
				show = !show;
				refresh_message(usermsg);
				process_listbox_selchange(listbox);
				continue;
			};
		};
		if (Number(src)!=Number(DOpus.listers.lastactive.activetab)) continue;
		if ((ctl=="listbox1") && (evnt=="selchange")) process_listbox_selchange(listbox);
	} while (msg.result);
	// Restore visibility of files and folders before exiting
	cmdstr = "Set HIDEFILTERFILENAME";
	if (dbg) DOpus.output(cmdstr);
	c.runcommand(cmdstr);
	cmdstr = "Set HIDEFILTERFOLDERS";
	if (dbg) DOpus.output(cmdstr);
	c.runcommand(cmdstr);
	return;
}

function minver(){
	var minver = (Script.vars.exists("minver")) ? Script.vars("minver") : "12";
	var isokay = DOpus.version.AtLeast(minver);
	if (!isokay){
		var str = "Requires DOpus version " + minver + " or later."
		DOpus.output(str, true);
	}
	return isokay;
}

function populate_listbox(lb){
	lb.RemoveItem(-1);
	lb.AddItem("Clear Selection(s)");
	var ext, extmap = DOpus.Create.Map();
	// Generate a map of extensions and counts of occurrences
	for (var i = 0; i < src.files.count; i++){
		ext = src.files(i).ext.toLowerCase();
		if (ext=="") ext = "(blank)";
		extmap(ext) = (extmap.exists(ext)) ? (extmap(ext) + 1) : 1;
	};
	if (extmap.count==0) return;
	// Add extensions and counts to the list ox
	var key, value;
	for (var e = new Enumerator(extmap); !e.atEnd(); e.moveNext())
	{
		key = e.item();
		value = extmap(key);
		lb.AddItem(key+" ("+value+")");
	};
}

function process_listbox_selchange(lb){
	var cmdstr;
	var itemvec = lb.value;
	if (itemvec.count==0){ // Nothing selected
		cmdstr = "Set HIDEFILTERFILENAME";
		if (dbg) DOpus.output(cmdstr);
		c.runcommand(cmdstr);
	};
	else if (itemvec(0).index==0){ // First item = Clear Selections
		cmdstr = "Set HIDEFILTERFILENAME";
		if (itemvec(0).selected){
			for (var i = 2; i < lb.count; i++) lb.DeselectItem(i);
			if (dbg) DOpus.output(cmdstr);
			c.runcommand(cmdstr);
		};
	}
	else{ // Build a list of selected extensions
		if (dbg) DOpus.output("itemvec.count = " + itemvec.count);
		var lst = "", blank = false;
		for (var i = 0; i < itemvec.count; i++){
			if (itemvec(i).selected){
				var a = itemvec(i).name.split(" ");
				if (a[0]=="(blank)") blank = true;
				else lst = (lst=="") ? a[0].slice(1) : lst+"|"+a[0].slice(1);
			};
		}; // Hide (or show) extensions as appropriate
		if ((lst!="") || (blank)){
			if ((lst!="") && (blank)) cmdstr = "((~(*.*))|(*.("+lst+")))";
			else if (blank) cmdstr = "(~(*.*))";
			else cmdstr = "(*.("+lst+"))";
			if (show) cmdstr = "~"+cmdstr;
			cmdstr = "Set HIDEFILTERFILENAME "+ cmdstr;
			if (dbg) DOpus.output(cmdstr);
			c.runcommand(cmdstr);
		};
	};
}

function refresh_message(msg){
	str = (show) ? "" : "un";
	msg.label = "Showing "+str+"matched items..";
}

function toggle_folders(){
	var cmdstr = "Set HIDEFILTERFOLDERS";
	if (!foldersarehidden) cmdstr = cmdstr+" *";
	if (dbg) DOpus.output(cmdstr);
	c.runcommand(cmdstr);
	foldersarehidden = !foldersarehidden;
}

==SCRIPT RESOURCES
<resources>
	<resource name="hidext" type="dialog">
		<dialog fontsize="8" height="150" lang="english" resize="yes" width="138">
			<control height="84" multisel="yes" name="listbox1" resize="wh" type="listbox" width="102" x="18" y="12" />
			<control height="14" name="button1" resize="y" title="Folders" type="button" width="30" x="18" y="108" />
			<control height="14" name="button2" resize="y" title="Quit" type="button" width="30" x="90" y="108" />
			<control height="14" name="button3" resize="y" title="Toggle" type="button" width="30" x="54" y="108" />
			<control halign="left" height="8" name="static1" resize="y" title="Static" type="static" width="102" x="18" y="132" />
		</dialog>
	</resource>
</resources>